==> vue3-components-0.2.28.tgz: package/es/customElement/src/customElement.js <==
import { defineComponent as N, getCurrentInstance as k, unref as S, isVNode as d, markRaw as V, createVNode as b, resolveComponent as v, mergeProps as A, toRef as O } from "vue";
import { customElementProps as h } from "./props.js";
import { getI18nKey as j, getValue as x, setValue as K } from "@tomiaa/utils";
import { useI18n as P } from "vue-i18n";
function R(n) {
  return typeof n == "function" || Object.prototype.toString.call(n) === "[object Object]" && !d(n);
}
const Y = N({
  name: "KCustomElement",
  props: h,
  setup(n, {
    slots: w
  }) {
    var i, y, g;
    let p = (e) => e;
    (g = (y = (i = k()) == null ? void 0 : i.appContext) == null ? void 0 : y.app) != null && g.__VUE_I18N_SYMBOL__ && (p = P().t);
    const a = Symbol("isSlot"), c = (e = []) => {
      let m;
      if (e = S(e), typeof e == "string") {
        const t = j(e);
        return t ? p(t) : e;
      }
      if (Array.isArray(e))
        return e.map(c);
      if (e.setup || e.render || d(e))
        return e = V(e), b(e, null, null);
      const f = {};
      for (const t in e)
        f[t] = S(e[t]);
      for (const t in e) {
        const r = typeof e[t] == "string" && j(e[t]);
        r && (f[t] = p(r));
      }
      const {
        el: o,
        children: C,
        vIf: E,
        slot: _,
        deepSlot: I = "default",
        ...l
      } = f;
      if (_)
        return {
          [I]: w[_],
          [a]: !0
        };
      if (E === !1 || f["v-if"] === !1)
        return;
      let s;
      if (typeof o == "string") {
        const t = console.warn;
        console.warn = () => {
        }, s = v(o), console.warn = t;
      } else
        ((o == null ? void 0 : o.setup) || (o == null ? void 0 : o.render) || d(o)) && (s = V(o));
      return f.prop && typeof f.prop == "string" && typeof n.model == "object" && (l.modelValue = x(e.prop || "", n.model), l["onUpdate:modelValue"] = (t) => {
        K(e.prop, t, n.model);
      }), b(s, A(l, {
        ref: (t) => {
          const r = e;
          typeof r.ref == "function" ? r.ref(t) : O(r, "ref").value = t;
        }
      }), R(m = (() => {
        let t = {};
        const r = c(C);
        if (!!r)
          return Array.isArray(r) ? (t.default = () => r.filter((u) => !u[a]), r.filter((u) => u[a]).forEach((u) => Object.assign(t, u))) : r[a] ? t = r : t.default = () => r, delete t[a], t;
      })()) ? m : {
        default: () => [m]
      });
    };
    return () => c(n.list);
  }
});
export {
  Y as default
};

==> vue3-components-0.2.30.tgz: package/es/customElement/src/customElement.js <==
import { defineComponent as N, getCurrentInstance as k, unref as S, isVNode as d, markRaw as V, createVNode as b, resolveComponent as v, mergeProps as A, toRef as O } from "vue";
import { customElementProps as h } from "./props.js";
import { getI18nKey as j, getValue as x, setValue as K } from "@tomiaa/utils";
import { useI18n as P } from "vue-i18n";
function R(n) {
  return typeof n == "function" || Object.prototype.toString.call(n) === "[object Object]" && !d(n);
}
const Y = /* @__PURE__ */ N({
  name: "KCustomElement",
  props: h,
  setup(n, {
    slots: w
  }) {
    var i, y, g;
    let p = (e) => e;
    (g = (y = (i = k()) == null ? void 0 : i.appContext) == null ? void 0 : y.app) != null && g.__VUE_I18N_SYMBOL__ && (p = P().t);
    const a = Symbol("isSlot"), c = (e = []) => {
      let m;
      if (e = S(e), typeof e == "string") {
        const t = j(e);
        return t ? p(t) : e;
      }
      if (Array.isArray(e))
        return e.map(c);
      if (e.setup || e.render || d(e))
        return e = V(e), b(e, null, null);
      const f = {};
      for (const t in e)
        f[t] = S(e[t]);
      for (const t in e) {
        const r = typeof e[t] == "string" && j(e[t]);
        r && (f[t] = p(r));
      }
      const {
        el: o,
        children: C,
        vIf: E,
        slot: _,
        deepSlot: I = "default",
        ...l
      } = f;
      if (_)
        return {
          // deepSlot 为传递给子组件的插槽名，默认使用父组件传递下来的插槽名
          [I]: w[_],
          // 用于判断父组件接受的是否为插槽
          [a]: !0
        };
      if (E === !1 || f["v-if"] === !1)
        return;
      let s;
      if (typeof o == "string") {
        const t = console.warn;
        console.warn = () => {
        }, s = v(o), console.warn = t;
      } else
        (o != null && o.setup || o != null && o.render || d(o)) && (s = V(o));
      return f.prop && typeof f.prop == "string" && typeof n.model == "object" && (l.modelValue = x(e.prop || "", n.model), l["onUpdate:modelValue"] = (t) => {
        K(e.prop, t, n.model);
      }), b(s, A(l, {
        ref: (t) => {
          const r = e;
          typeof r.ref == "function" ? r.ref(t) : O(r, "ref").value = t;
        }
      }), R(m = (() => {
        let t = {};
        const r = c(C);
        if (r)
          return Array.isArray(r) ? (t.default = () => r.filter((u) => !u[a]), r.filter((u) => u[a]).forEach((u) => Object.assign(t, u))) : r[a] ? t = r : t.default = () => r, delete t[a], t;
      })()) ? m : {
        default: () => [m]
      });
    };
    return () => c(n.list);
  }
});
export {
  Y as default
};
